@@ -3,6 +3,7 @@ use std::io;
 use std::path::{Path, PathBuf};
 
 use either::Either;
+use owo_colors::OwoColorize;
 use thiserror::Error;
 use uv_auth::CredentialsCache;
 use uv_distribution_filename::DistExtension;
@@ -226,10 +227,12 @@ impl LoweredRequirement {
                                     name.as_ref().is_some_and(|name| *name == index)
                                 })
                             else {
-                                return Err(LoweringError::MissingIndex(
-                                    requirement.name.clone(),
+                                let hint = missing_index_hint(locations, &index);
+                                return Err(LoweringError::MissingIndex {
+                                    package: requirement.name.clone(),
                                     index,
-                                ));
+                                    hint,
+                                });
                             };
                             if let Some(credentials) = index.credentials() {
                                 credentials_cache.store_credentials(index.raw_url(), credentials);
@@ -462,10 +465,12 @@ impl LoweredRequirement {
                                     name.as_ref().is_some_and(|name| *name == index)
                                 })
                             else {
-                                return Err(LoweringError::MissingIndex(
-                                    requirement.name.clone(),
+                                let hint = missing_index_hint(locations, &index);
+                                return Err(LoweringError::MissingIndex {
+                                    package: requirement.name.clone(),
                                     index,
-                                ));
+                                    hint,
+                                });
                             };
                             if let Some(credentials) = index.credentials() {
                                 credentials_cache.store_credentials(index.raw_url(), credentials);
@@ -528,8 +533,12 @@ pub enum LoweringError {
     MoreThanOneGitRef,
     #[error(transparent)]
     GitUrlParse(#[from] GitUrlParseError),
-    #[error("Package `{0}` references an undeclared index: `{1}`")]
-    MissingIndex(PackageName, IndexName),
+    #[error("Package `{package}` references an undeclared index: `{index}`{}", if let Some(hint) = hint { format!("\n\n{}{} {hint}", "hint".bold().cyan(), ":".bold()) } else { String::new() })]
+    MissingIndex {
+        package: PackageName,
+        index: IndexName,
+        hint: Option<String>,
+    },
     #[error("Workspace members are not allowed in non-workspace contexts")]
     WorkspaceMember,
     #[error(transparent)]
@@ -579,6 +588,29 @@ impl std::fmt::Display for SourceKind {
     }
 }
 
+/// Generate a hint for a missing index if the index name is found in a configuration file
+/// (e.g., `uv.toml`) rather than in the project's `pyproject.toml`.
+fn missing_index_hint(locations: &IndexLocations, index: &IndexName) -> Option<String> {
+    let config_index = locations
+        .simple_indexes()
+        .filter(|idx| !matches!(idx.origin, Some(Origin::Cli)))
+        .find(|idx| idx.name.as_ref().is_some_and(|name| *name == *index));
+
+    config_index.and_then(|idx| {
+        let source = match idx.origin {
+            Some(Origin::User) => "a user-level `uv.toml`",
+            Some(Origin::System) => "a system-level `uv.toml`",
+            Some(Origin::Project) => "a project-level `uv.toml`",
+            Some(Origin::Cli | Origin::RequirementsTxt) | None => return None,
+        };
+        Some(format!(
+            "Index `{index}` was found in {source}, but indexes \
+             referenced via `tool.uv.sources` must be defined in the project's \
+             `pyproject.toml`"
+        ))
+    })
+}
+
 /// Convert a Git source into a [`RequirementSource`].
 fn git_source(
     git: &DisplaySafeUrl,
