@@ -146,7 +146,7 @@ pub(crate) async fn build_frontend(
         no_config,
         python_preference,
         python_downloads,
-        concurrency,
+        &concurrency,
         cache,
         printer,
         preview,
@@ -193,7 +193,7 @@ async fn build_impl(
     no_config: bool,
     python_preference: PythonPreference,
     python_downloads: PythonDownloads,
-    concurrency: Concurrency,
+    concurrency: &Concurrency,
     cache: &Cache,
     printer: Printer,
     preview: Preview,
@@ -469,7 +469,7 @@ async fn build_package(
     keyring_provider: KeyringProviderType,
     exclude_newer: ExcludeNewer,
     sources: NoSources,
-    concurrency: Concurrency,
+    concurrency: &Concurrency,
     build_options: &BuildOptions,
     sdist: bool,
     wheel: bool,
@@ -630,7 +630,7 @@ async fn build_package(
         exclude_newer,
         sources.clone(),
         workspace_cache,
-        concurrency,
+        concurrency.clone(),
         preview,
     );
 
