@@ -307,7 +307,7 @@ pub(crate) async fn remove(
             &client_builder,
             &state,
             Box::new(DefaultResolveLogger),
-            concurrency,
+            &concurrency,
             cache,
             &WorkspaceCache::default(),
             printer,
@@ -365,7 +365,7 @@ pub(crate) async fn remove(
         &state,
         Box::new(DefaultInstallLogger),
         installer_metadata,
-        concurrency,
+        &concurrency,
         cache,
         WorkspaceCache::default(),
         DryRun::Disabled,
