@@ -107,7 +107,7 @@ pub(crate) async fn project_version(
                 client_builder,
                 python_preference,
                 python_downloads,
-                concurrency,
+                &concurrency,
                 no_config,
                 cache,
                 short,
@@ -328,7 +328,7 @@ pub(crate) async fn project_version(
             python_preference,
             python_downloads,
             installer_metadata,
-            concurrency,
+            &concurrency,
             no_config,
             cache,
             printer,
@@ -437,7 +437,7 @@ async fn print_frozen_version(
     client_builder: BaseClientBuilder<'_>,
     python_preference: PythonPreference,
     python_downloads: PythonDownloads,
-    concurrency: Concurrency,
+    concurrency: &Concurrency,
     no_config: bool,
     cache: &Cache,
     short: bool,
@@ -535,7 +535,7 @@ async fn lock_and_sync(
     python_preference: PythonPreference,
     python_downloads: PythonDownloads,
     installer_metadata: bool,
-    concurrency: Concurrency,
+    concurrency: &Concurrency,
     no_config: bool,
     cache: &Cache,
     printer: Printer,
