@@ -16,8 +16,7 @@ use wiremock::matchers::{any, method};
 use wiremock::{Mock, MockServer, Request, ResponseTemplate};
 
 use uv_static::EnvVars;
-
-use crate::common::{TestContext, uv_snapshot};
+use uv_test::{TestContext, uv_snapshot};
 
 /// Creates a CONNECT tunnel proxy that forwards connections to the target.
 ///
@@ -237,7 +236,7 @@ fn read_timeout_server() -> (String, impl Drop) {
 /// Check the simple index error message when the server returns HTTP status 500, a retryable error.
 #[tokio::test]
 async fn simple_http_500() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (_server_drop_guard, mock_server_uri) = http_error_server().await;
 
@@ -262,7 +261,7 @@ async fn simple_http_500() {
 /// Check the simple index error message when the server returns a retryable IO error.
 #[tokio::test]
 async fn simple_io_err() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (_server_drop_guard, mock_server_uri) = io_error_server().await;
 
@@ -289,7 +288,7 @@ async fn simple_io_err() {
 /// Check the find links error message when the server returns HTTP status 500, a retryable error.
 #[tokio::test]
 async fn find_links_http_500() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (_server_drop_guard, mock_server_uri) = http_error_server().await;
 
@@ -316,7 +315,7 @@ async fn find_links_http_500() {
 /// Check the find links error message when the server returns a retryable IO error.
 #[tokio::test]
 async fn find_links_io_error() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (_server_drop_guard, mock_server_uri) = io_error_server().await;
 
@@ -346,7 +345,7 @@ async fn find_links_io_error() {
 /// returns different kinds of retryable errors.
 #[tokio::test]
 async fn find_links_mixed_error() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (_server_drop_guard, mock_server_uri) = mixed_error_server().await;
 
@@ -374,7 +373,7 @@ async fn find_links_mixed_error() {
 /// error.
 #[tokio::test]
 async fn direct_url_http_500() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (_server_drop_guard, mock_server_uri) = http_error_server().await;
 
@@ -401,7 +400,7 @@ async fn direct_url_http_500() {
 /// Check the direct package URL error message when the server returns a retryable IO error.
 #[tokio::test]
 async fn direct_url_io_error() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (_server_drop_guard, mock_server_uri) = io_error_server().await;
 
@@ -431,7 +430,7 @@ async fn direct_url_io_error() {
 /// different kinds of retryable errors.
 #[tokio::test]
 async fn direct_url_mixed_error() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (_server_drop_guard, mock_server_uri) = mixed_error_server().await;
 
@@ -485,7 +484,7 @@ fn write_python_downloads_json(context: &TestContext, mock_server_uri: &String)
 /// error.
 #[tokio::test]
 async fn python_install_http_500() {
-    let context = TestContext::new("3.12")
+    let context = uv_test::test_context!("3.12")
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
@@ -516,7 +515,7 @@ async fn python_install_http_500() {
 /// Check the Python install error message when the server returns a retryable IO error.
 #[tokio::test]
 async fn python_install_io_error() {
-    let context = TestContext::new("3.12")
+    let context = uv_test::test_context!("3.12")
         .with_filtered_python_keys()
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
@@ -548,7 +547,7 @@ async fn python_install_io_error() {
 
 #[tokio::test]
 async fn install_http_retries() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let server = MockServer::start().await;
 
@@ -621,7 +620,7 @@ async fn install_http_retries() {
 
 #[tokio::test]
 async fn install_http_retry_low_level() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let server = MockServer::start().await;
 
@@ -656,7 +655,7 @@ async fn install_http_retry_low_level() {
 /// Test problem details with a 403 error containing license compliance information
 #[tokio::test]
 async fn rfc9457_problem_details_license_violation() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let server = MockServer::start().await;
 
@@ -704,7 +703,7 @@ async fn rfc9457_problem_details_license_violation() {
 /// Test that invalid proxy URL in uv.toml produces a helpful error message.
 #[tokio::test]
 async fn proxy_invalid_url_in_uv_toml() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let uv_toml = context.temp_dir.child("uv.toml");
     uv_toml
@@ -735,7 +734,7 @@ async fn proxy_invalid_url_in_uv_toml() {
 /// Test that invalid proxy URL (not a URL) in uv.toml produces a helpful error message.
 #[tokio::test]
 async fn proxy_invalid_url_not_a_url_in_uv_toml() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let uv_toml = context.temp_dir.child("uv.toml");
     uv_toml
@@ -767,7 +766,7 @@ async fn proxy_invalid_url_not_a_url_in_uv_toml() {
 #[cfg(feature = "test-pypi")]
 #[tokio::test]
 async fn proxy_valid_url_in_uv_toml() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let target_server = MockServer::start().await;
     Mock::given(any())
@@ -826,7 +825,7 @@ async fn proxy_valid_url_in_uv_toml() {
 #[cfg(feature = "test-pypi")]
 #[test]
 fn proxy_https_proxy_in_uv_toml() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let proxy_addr = start_connect_tunnel_proxy();
     let proxy_uri = format!("http://{proxy_addr}");
@@ -863,7 +862,7 @@ fn proxy_https_proxy_in_uv_toml() {
 #[cfg(feature = "test-pypi")]
 #[tokio::test]
 async fn proxy_no_proxy_in_uv_toml() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let target_server = MockServer::start().await;
     mock_simple_api(&target_server).await;
@@ -931,7 +930,7 @@ no-proxy = ["{target_host}"]
 #[cfg(feature = "test-pypi")]
 #[tokio::test]
 async fn proxy_schemeless_url_in_uv_toml() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let target_server = MockServer::start().await;
     Mock::given(any())
@@ -994,7 +993,7 @@ async fn proxy_schemeless_url_in_uv_toml() {
 
 #[test]
 fn connect_timeout_index() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create a server that never responds, causing a timeout for our requests.
     let listener = std::net::TcpListener::bind("127.0.0.1:0").unwrap();
@@ -1029,7 +1028,7 @@ fn connect_timeout_index() {
 
 #[test]
 fn connect_timeout_stream() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     // Create a server that never responds, causing a timeout for our requests.
     let listener = std::net::TcpListener::bind("127.0.0.1:0").unwrap();
@@ -1063,7 +1062,7 @@ fn connect_timeout_stream() {
 
 #[tokio::test]
 async fn retry_read_timeout_index() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (server, _guard) = read_timeout_server();
 
@@ -1090,7 +1089,7 @@ async fn retry_read_timeout_index() {
 
 #[tokio::test]
 async fn retry_read_timeout_stream() {
-    let context = TestContext::new("3.12");
+    let context = uv_test::test_context!("3.12");
 
     let (server, _guard) = read_timeout_server();
 
